@@ -90,6 +90,7 @@ FLASH_DISK_RE = re.compile(r"Mass|Storage|Disk", re.I)
 class UdevadmDevice(object):
     __slots__ = (
         "_environment",
+        "_name",
         "_bits",
         "_stack",
         "_bus",
@@ -99,8 +100,9 @@ class UdevadmDevice(object):
         "_vendor",
         "_vendor_id",)
 
-    def __init__(self, environment, bits=None, stack=[]):
+    def __init__(self, environment, name, bits=None, stack=[]):
         self._environment = environment
+        self._name = name
         self._bits = bits
         self._stack = stack
         self._bus = None
@@ -117,6 +119,11 @@ class UdevadmDevice(object):
             type(self).__name__, self.bus, vid, pid,
             self.product))
 
+    @property
+    def name(self):
+        if self._name is not None:
+            return self._name
+
     @property
     def bus(self):
         if self._bus is not None:
@@ -150,12 +157,13 @@ class UdevadmDevice(object):
                 devtype = self._environment["DEVTYPE"]
                 if devtype in ("wlan", "wimax"):
                     return "WIRELESS"
-            # Ralink wireless
+            # Ralink and realtek SDIO wireless
             if "INTERFACE" in self._environment:
                 if (self.driver and
                     self.driver.startswith('rt') and
-                    self._environment["INTERFACE"].startswith('ra')
-                ):
+                    (self._environment["INTERFACE"].startswith('ra') or
+                     self._environment["INTERFACE"].startswith('wlan')
+                     )):
                     return "WIRELESS"
             return "NETWORK"
 
@@ -395,7 +403,7 @@ class UdevadmDevice(object):
         # A few devices may have no self.product but carry PRODUCT data in
         # their environment.
         if ((self.product or self._environment.get("PRODUCT")) and
-                not None in (self.vendor_id, self.product_id)):
+                None not in (self.vendor_id, self.product_id)):
             return "OTHER"
 
         # Limbo of devices I couldn't otherwise categorize. In practice
@@ -639,7 +647,7 @@ class UdevadmDevice(object):
     def as_json(self):
         attributes = ("path", "bus", "category", "driver", "product_id",
                       "vendor_id", "subproduct_id", "subvendor_id", "product",
-                      "vendor", "interface",)
+                      "vendor", "interface", "name")
 
         return {a: getattr(self, a) for a in attributes if getattr(self, a)}
 
@@ -715,8 +723,9 @@ class UdevadmParser(object):
             if not record:
                 continue
 
-            # Determine path and environment
+            # Determine path, name and environment
             path = None
+            name = None
             element = None
             environment = {}
             for line in record.splitlines():
@@ -732,6 +741,8 @@ class UdevadmParser(object):
 
                 if key == "P":
                     path = value
+                elif key == "N":
+                    name = value
                 elif key == "E":
                     key_match = multi_pattern.match(value)
                     if not key_match:
@@ -749,16 +760,17 @@ class UdevadmParser(object):
             # Set default DEVPATH
             environment.setdefault("DEVPATH", path)
 
-            device = self.device_factory(environment, self.bits, list(stack))
+            device = self.device_factory(
+                environment, name, self.bits, list(stack))
             if not self._ignoreDevice(device):
                 if device._raw_path in self.devices:
                     if self.devices[device._raw_path].category == 'CARDREADER':
                         [
                             setattr(self.devices[device._raw_path],
-                                    key, getattr(device, key))
-                            for key in (
+                                    device_key, getattr(device, device_key))
+                            for device_key in (
                                 "product", "vendor", "product_id", "vendor_id")
-                            if getattr(device, key) is not None
+                            if getattr(device, device_key) is not None
                         ]
                     elif device.category != "OTHER":
                         self.devices[device._raw_path] = device
